@@ -209,7 +209,8 @@ def paint_override(self, augCanvas):
     self.plot.set_ylim(augCanvas.spectplot.get_ylim())
     data = [line.get_data() for line in augCanvas.spectplot.lines]
     texts = copy.copy(augCanvas.ms)
-    if augCanvas.ds and augCanvas.ds.headers:
+    if augCanvas.ds and augCanvas.ds.headers and\
+            cf.settings().value("view/legend", type=bool):
         legend = augCanvas.spectplot.get_legend().get_texts()
         [gt.pop_plot(*line, self.plot, texts, i, legend[i].get_text(),
                      not (cf.settings().value(
