@@ -45,6 +45,7 @@ def settings():
                ("timstof/ms_sampling", 500),
                ("timstof/ms_bins", 0.001),
                ("timstof/mob_sampling", 5000),
+               ("timstof/fastchrom", True),
                ("timstof/mob_bins", 0.0001)}
     [settings.setValue(*i)
      for i in defvals if not settings.contains(i[0])]
@@ -154,6 +155,9 @@ def dial(parent):
         config))
     timstoflayout.addLayout(posvarconf(
         "Bins - mobility", "timstof/mob_bins", config, "nonint"))
+    timstoflayout.addWidget(checkboxconf(
+        "Fast chromatogram (slightly less precise, much faster)",
+        "timstof/fastchrom", config))
     tabs.addTab(timstoftab, "TimsTOF")
 
     viewtab = QtWidgets.QWidget()
