@@ -178,7 +178,7 @@ class BrukerTimsDataset(Dataset):
             # devNote - summing is fast, asarray is fast, iterating is slow.
             intensities = np.asarray([
                 np.sum(i['intensity']) for i in self.dataset.query_iter(
-                    self.dataset.ms1_frames, columns=('intensity',))])
+                    np.arange(self.dataset.max_frame)+1, columns=('intensity',))])
         logger.info("DONE: getting timsTOF chromatogram")
         return [[times, intensities]]
 
@@ -221,8 +221,6 @@ class BrukerTimsDataset(Dataset):
     @logdecor
     def get_mzmobpeakchrom(self, startmz, endmz, startmob, endmob):
         """getting mz/mob peak ion chromatogram..."""
-        boundsmz = sorted([startmz, endmz])
-        boundsmob = sorted([startmob, endmob])
         intensity = np.divide([
             np.sum(i['intensity'][dt.argsubselect_2d(
                 i['mz'], startmz, endmz,
@@ -233,6 +231,23 @@ class BrukerTimsDataset(Dataset):
             np.clip(self.chromatograms[0][1], np.finfo(np.float32).eps, None))
         return intensity
 
+    @logdecor
+    def get_mzmobpeakchroms(self, intranges):
+        """getting mz/mob peak ion chromatograms..."""
+        intensities = [[]] * len(intranges)
+        for i in self.dataset.query_iter(
+            np.arange(self.dataset.max_frame)+1,
+            columns=('intensity', 'mz', 'inv_ion_mobility')):
+            for j,k in enumerate(intranges):
+                intensities[j].append(np.sum(i['intensity'][dt.argsubselect_2d(
+                    i['mz'], k[0], k[1], i['inv_ion_mobility'], k[2], k[3])]))
+        for i,j in enumerate(intensities):
+            if j:
+                intensities[i] = np.divide(intensities[i],
+                    np.clip(self.chromatograms[0][1],
+                            np.finfo(np.float32).eps, None))
+        return intensities
+
     def get_subspace(self, xax, subselect, start, end, bins,
                      mint=None, maxt=None):
         mint = mint or self.mintime
