@@ -411,6 +411,13 @@ def get_intensity(row, ds, drls):
     intensity = ds.get_mzmobpeakchrom(startm, endm, startmob, endmob)
     return intensity
 
+def get_intensrange(row, ds, drls):
+    startm, endm = drl.get_range(drl.floatize(drls['pt'], row, 1),
+                                 drl.floatize(drls['pt'], row, 2))
+    startmob, endmob = drl.get_range(drl.floatize(drls['pt'], row, 4),
+                                     drl.floatize(drls['pt'], row, 5))
+    return [startm, endm, startmob, endmob]
+
 
 def get_daughterset(ds, drls):
     """Fuction to acquire the curves of the daugher ions"""
@@ -418,16 +425,28 @@ def get_daughterset(ds, drls):
     names = []
     times = np.concatenate([sub[0] - drls['tshift'].value()
                             for sub in ds.chromatograms])
+    intensityranges = [None] * drls['pt'].rowCount()
+    ids = []
+    for row in range(drls['dt'].rowCount()):
+        if drls['dt'].cellWidget(row, 0).checkState() == 2:
+            ids.append(row)
+            for i in range(drls['cors'].value()):
+                cor = drls['dt'].cellWidget(row, 1+i*2).currentIndex() - 1
+                if cor not in (-2, -1):
+                    ids.append(cor)
+    for i in np.unique(ids):
+        intensityranges[i] = get_intensrange(i, ds, drls)
+    intensitycache = ds.get_mzmobpeakchroms(intensityranges)
     intensities = []
     for row in range(drls['dt'].rowCount()):
         if drls['dt'].cellWidget(row, 0).checkState() == 2:
-            intensity = get_intensity(row, ds, drls)
+            intensity = intensitycache[row]
             corlist = []
             for i in range(drls['cors'].value()):
                 cor = drls['dt'].cellWidget(row, 1+i*2).currentIndex() - 1
                 if cor not in (-2, -1):
                     factor = drl.floatize(drls['dt'], row, 2+i*2, False)
-                    correction = get_intensity(cor, ds, drls) * factor
+                    correction = intensitycache[row] * factor
                     intensity = intensity - correction
                     corlist.append("{} * {}".format(
                         drls['dt'].item(row, 2+i*2).text(),
