@@ -25,17 +25,23 @@ def floatize(table, row, column, nonneg=True):
     return outfloat
 
 
+def get_range(center, width):
+    start = center - width / 2
+    end = center + width / 2
+    return start, end
+
+
 def get_subargs(tab, row, masses, col1, col2):
-    startm = floatize(tab, row, col1) - (floatize(tab, row, col2) / 2)
-    endm = floatize(tab, row, col1) + (floatize(tab, row, col2) / 2)
+    startm, endm = get_range(floatize(tab, row, col1),
+                             floatize(tab, row, col2))
     massargs = dt.argsubselect(masses, startm, endm)
     return massargs
 
 
 def get_intensity(row, ds, drls):
     # prevent division by 0
-    startm = floatize(drls['pt'], row, 1) - (floatize(drls['pt'], row, 2) / 2)
-    endm = floatize(drls['pt'], row, 1) + (floatize(drls['pt'], row, 2) / 2)
+    startm, endm = get_range(floatize(drls['pt'], row, 1),
+                             floatize(drls['pt'], row, 2))
     intensity = ds.get_peakchrom(startm, endm)
     return intensity
 
