@@ -7,6 +7,7 @@ from matplotlib.widgets import SpanSelector
 import numpy as np
 import prasopes.datatools as dt
 import prasopes.config as cf
+import prasopes.datasets as ds
 import matplotlib
 matplotlib.use("Qt5Agg")
 
@@ -274,6 +275,7 @@ def pick_times(x_min, x_max, augCanvas):
     plot_subtime(augCanvas)
 
 
+@ds.logdecor
 def shift_times(event, augCanvas):
     """shifts times when arrow is pressed"""
     if event.key() == QtCore.Qt.Key_Left:
@@ -282,13 +284,13 @@ def shift_times(event, augCanvas):
         move = +1
     else:
         return
-    if not np.array_equal(augCanvas.chrom['timesarg'], []):
-        x_min, x_max = augCanvas.chrom['t_start'], augCanvas.chrom['t_end']
-        alltimes = np.concatenate([subset['chrom_dat'][0] for subset
-                                   in augCanvas.ds])
+    if not np.array_equal(augCanvas.ds.get_chromargs(), []):
+        x_min, x_max = augCanvas.ds.mintime, augCanvas.ds.maxtime
+        alltimes = np.concatenate([subset[0] for subset
+                                   in augCanvas.ds.chromatograms])
         times = dt.argsubselect(alltimes, x_min, x_max) + move
         goodtimes = np.where((times < len(alltimes)) & ~(times < 0))[0]
-        if not np.array_equal(goodtimes, []):
+        if goodtimes.size:
             x_min, x_max = alltimes[times[goodtimes[[0, -1]]]]
             pick_times(x_min, x_max, augCanvas)
 
@@ -415,7 +417,7 @@ def legendize(rawlegend, augCanvas):
             else:
                 text = "{}ms^{} {:.2f}@{:.1f}V; m/z = {:.1f}-{:.1f}".format(
                         marks[int(wut[0])], *wut[1:])
-        elif augCanvas.ds.machtype in (57, 63):
+        elif augCanvas.ds.machtype in (57, 60, 63):
             if int(wut[1]) == 1:
                 text = "{}ms; m/z = {:.1f}-{:.1f}".format(
                         marks[int(wut[0])], *wut[2:])
